@@ -13,7 +13,7 @@ from starlette.requests import HTTPConnection
 from starlette.types import ASGIApp, Message, Receive, Scope, Send
 
 from starlette_session.backends import (AioRedisSessionBackend, BackendType,
-                                        RedisSessionBackend)
+                                        RedisSessionBackend, MemcacheSessionBackend, AioMemcacheSessionBackend)
 from starlette_session.interfaces import ISessionBackend
 
 
@@ -123,6 +123,10 @@ class SessionMiddleware:
             return
         elif self.backend_type == BackendType.aioRedis:
             return AioRedisSessionBackend(backend_db_client)
+        elif self.backend_type == BackendType.memcache:
+            return MemcacheSessionBackend(backend_db_client)
+        elif self.backend_type == BackendType.aioMemcache:
+            return AioMemcacheSessionBackend(backend_db_client)
         else:
             raise UnknownPredefinedBackend()
 
